==> Rmixmod_1.0.tar.gz: Rmixmod/src/MIXMOD/XEMBICCriterion.h <==
/***************************************************************************
                             SRC/MIXMOD/XEMBICCriterion.h  description
    copyright            : (C) MIXMOD Team - 2001-2011
    email                : contact@mixmod.org
 ***************************************************************************/

/***************************************************************************
    This file is part of MIXMOD
    
    MIXMOD is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    MIXMOD is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with MIXMOD.  If not, see <http://www.gnu.org/licenses/>.

    All informations available on : http://www.mixmod.org                                                                                               
***************************************************************************/
#ifndef XEMBICCRITERION_H
#define XEMBICCRITERION_H

#include "XEMCriterion.h"
#include "XEMModel.h"

/**
  @brief Derived class of XEMCriterion for BIC Criterion
  @author F Langrognet & A Echenim
  */

class XEMBICCriterion : public XEMCriterion{

public:

	/// Default Constructor
	XEMBICCriterion();


	/// Destructor
	virtual ~XEMBICCriterion();
  
  XEMCriterionName getCriterionName() const;

	/// Run method
	void run(XEMModel * model, double & value, XEMErrorType & error);
	
};

inline XEMCriterionName XEMBICCriterion::getCriterionName() const{
  return BIC;
}

#endif

==> Rmixmod_1.1.0.tar.gz: Rmixmod/src/MIXMOD/XEMBICCriterion.h <==
/***************************************************************************
                             SRC/MIXMOD/XEMBICCriterion.h  description
    copyright            : (C) MIXMOD Team - 2001-2011
    email                : contact@mixmod.org
 ***************************************************************************/

/***************************************************************************
    This file is part of MIXMOD
    
    MIXMOD is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    MIXMOD is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with MIXMOD.  If not, see <http://www.gnu.org/licenses/>.

    All informations available on : http://www.mixmod.org                                                                                               
***************************************************************************/
#ifndef XEMBICCRITERION_H
#define XEMBICCRITERION_H

#include "XEMCriterion.h"

/**
  @brief Derived class of XEMCriterion for BIC Criterion
  @author F Langrognet & A Echenim
  */

class XEMBICCriterion : public XEMCriterion{

public:

	/// Default Constructor
	XEMBICCriterion(XEMModel * model);

	/// Destructor
	virtual ~XEMBICCriterion();

	/// Run method
	virtual void run(XEMCriterionOutput & output);
	
};

#endif
